is_git_repository

Function is_git_repository 

pub fn is_git_repository(path: &Path) -> bool
Checks if a path contains a Git repository (regular or bare).

Arguments

  • path - The path to check for a Git repository

Returns

  • true if the path is a valid Git repository (regular or bare)
  • false if neither repository marker exists