Module lockfile_dependency_ref

Module lockfile_dependency_ref 

Lockfile dependency reference handling.

This module provides a structured way to parse and format the dependency references that appear in the lockfile’s dependencies arrays. These use a specific compact format designed for lockfile serialization.

Structs

LockfileDependencyRef
A structured representation of a lockfile dependency reference.