LockedResourceBuilder

Struct LockedResourceBuilder 

pub struct LockedResourceBuilder { /* private fields */ }
Builder for creating LockedResource instances.

This builder helps address clippy warnings about functions with too many arguments by providing a fluent interface for constructing LockedResource instances.

Implementations

Source

impl LockedResourceBuilder

pub fn new( name: String, path: String, checksum: String, installed_at: String, resource_type: ResourceType, ) -> Self

Create a new builder with the required fields.

pub fn source(self, source: Option<String>) -> Self

Set the source repository name.

pub fn url(self, url: Option<String>) -> Self

Set the source repository URL.

pub fn version(self, version: Option<String>) -> Self

Set the version.

pub fn resolved_commit(self, resolved_commit: Option<String>) -> Self

Set the resolved commit.

pub fn dependencies(self, dependencies: Vec<String>) -> Self

Set the dependencies.

pub fn tool(self, tool: Option<String>) -> Self

Set the tool.

pub fn manifest_alias(self, manifest_alias: Option<String>) -> Self

Set the manifest alias.

pub fn applied_patches(self, applied_patches: BTreeMap<String, Value>) -> Self

Set the applied patches.

pub fn install(self, install: Option<bool>) -> Self

Set the install flag.

pub fn context_checksum(self, context_checksum: Option<String>) -> Self

Set the context checksum.

pub fn variant_inputs(self, variant_inputs: VariantInputs) -> Self

Set the variant inputs.

pub fn is_private(self, is_private: bool) -> Self

Set the is_private flag.

pub fn approximate_token_count(self, count: Option<u64>) -> Self

Set the approximate token count.

pub fn build(self) -> LockedResource

Build the LockedResource.