pub struct ResourceId { /* private fields */ }Expand description
Unique identifier for a resource in the lockfile.
This struct ensures type-safe identification of lockfile entries by combining the resource name, source, and tool. Resources are considered unique when they have distinct combinations of these fields:
- Same name, different sources: Different repositories providing same-named resources
- Same name, different tools: Resources used by different tools (e.g., Claude Code vs OpenCode)
- Same name and source, different tools: Transitive dependencies inherited from different parent tools
Examples
use agpm_cli::lockfile::ResourceId;
use agpm_cli::core::ResourceType;
// Local resource (no source)
let local = ResourceId::new("my-agent", None::<String>, Some("claude-code"), ResourceType::Agent, "default".to_string());
// Git resource from a source
let git = ResourceId::new("shared-agent", Some("community"), Some("claude-code"), ResourceType::Agent, "default".to_string());Implementations
Sourceimpl ResourceId
impl ResourceId
Sourcepub fn new(
name: impl Into<String>,
source: Option<impl Into<String>>,
tool: Option<impl Into<String>>,
resource_type: ResourceType,
variant_inputs_hash: String,
) -> Self
pub fn new( name: impl Into<String>, source: Option<impl Into<String>>, tool: Option<impl Into<String>>, resource_type: ResourceType, variant_inputs_hash: String, ) -> Self
Create a new ResourceId with pre-computed hash
Sourcepub fn from_resource(resource: &LockedResource) -> Self
pub fn from_resource(resource: &LockedResource) -> Self
Create a ResourceId from a LockedResource
Sourcepub fn resource_type(&self) -> ResourceType
pub fn resource_type(&self) -> ResourceType
Resource type accessor.
Sourcepub fn variant_inputs_hash(&self) -> &str
pub fn variant_inputs_hash(&self) -> &str
Get the variant_inputs_hash for this resource ID.