pub enum SourceContext {
Local(PathBuf),
Git(PathBuf),
Remote(String),
}Expand description
Context for determining how to generate canonical dependency names.
Different source contexts require different naming strategies:
- Local dependencies use paths relative to the manifest directory
- Git dependencies use paths relative to the repository root
- Remote dependencies may have other naming conventions
Variants
Local(PathBuf)
Local filesystem dependency relative to manifest directory
Git(PathBuf)
Git repository dependency with repository root path
Remote(String)
Remote source with source name (for backward compatibility)
Implementations
Sourceimpl SourceContext
impl SourceContext
Sourcepub fn local(manifest_dir: impl Into<PathBuf>) -> Self
pub fn local(manifest_dir: impl Into<PathBuf>) -> Self
Create a local source context from a manifest directory path
Sourcepub fn git(repo_root: impl Into<PathBuf>) -> Self
pub fn git(repo_root: impl Into<PathBuf>) -> Self
Create a Git source context from a repository root path