pub struct VersionEntry {
pub source: String,
pub url: String,
pub version: Option<String>,
pub resolved_sha: Option<String>,
pub resolved_version: Option<String>,
pub resolution_mode: ResolutionMode,
}Expand description
Version resolution entry tracking source and version to SHA mapping
Fields
source: StringSource name from manifest
url: StringSource URL (Git repository)
version: Option<String>Version specification (tag, branch, commit, or None for HEAD)
resolved_sha: Option<String>Resolved SHA-1 hash (populated during resolution)
resolved_version: Option<String>Resolved version (e.g., “latest” -> “v2.0.0”)
resolution_mode: ResolutionModeResolution mode used for this entry
Implementations
Sourceimpl VersionEntry
impl VersionEntry
Sourcepub fn format_display(&self) -> String
pub fn format_display(&self) -> String
Format the version entry for display in progress UI.
Formats as: source@version or source@HEAD if no version specified.
Examples
let entry = VersionEntry {
source: "community".to_string(),
url: "https://github.com/example/repo.git".to_string(),
version: Some("v1.0.0".to_string()),
resolved_sha: None,
resolved_version: None,
resolution_mode: ResolutionMode::Version,
};
assert_eq!(entry.format_display(), "community@v1.0.0");Sourcepub fn unique_key(&self) -> String
pub fn unique_key(&self) -> String
Create a unique key for tracking this entry in the progress window.
Uses source and version to create a unique identifier.