Template context building for AGPM resource installation.
This module provides structures and methods for building the template context that will be available to Markdown templates during rendering.
Structs
- Context
With Checksum - A cached Tera context with pre-computed checksum for performance.
- Dependency
Data - Complete data about a dependency for template embedding.
- Resource
Metadata - Metadata about the current resource being rendered.
- Template
Context Builder - Template context builder for AGPM resource installation.