read_text_file

Function read_text_file 

pub fn read_text_file(path: &Path) -> Result<String>
Reads a text file with proper error handling and context.

Arguments

  • path - The path to the file to read

Returns

The contents of the file as a String

Errors

Returns an error with context if the file cannot be read