pub struct PatternExpansionService { /* private fields */ }Expand description
Service for pattern expansion and resolution.
Handles expansion of glob patterns to concrete dependencies and maintains mappings between concrete files and their source patterns.
Implementations
Sourceimpl PatternExpansionService
impl PatternExpansionService
Sourcepub async fn expand_pattern(
&self,
core: &ResolutionCore,
dep: &ResourceDependency,
resource_type: ResourceType,
prepared_versions: &DashMap<String, PreparedSourceVersion>,
) -> Result<Vec<(String, ResourceDependency)>>
pub async fn expand_pattern( &self, core: &ResolutionCore, dep: &ResourceDependency, resource_type: ResourceType, prepared_versions: &DashMap<String, PreparedSourceVersion>, ) -> Result<Vec<(String, ResourceDependency)>>
Expand a pattern dependency to concrete dependencies.
Takes a glob pattern like “agents/*.md” and expands it to concrete file paths like [“agents/foo.md”, “agents/bar.md”].
Arguments
core- The resolution core with cache and source managerdep- The pattern dependency to expandresource_type- The type of resource being expanded
Returns
List of (name, concrete_dependency) tuples
Sourcepub fn get_pattern_alias(
&self,
resource_type: ResourceType,
name: &str,
) -> Option<Ref<'_, (ResourceType, String), String>>
pub fn get_pattern_alias( &self, resource_type: ResourceType, name: &str, ) -> Option<Ref<'_, (ResourceType, String), String>>
Sourcepub fn add_pattern_alias(
&self,
resource_type: ResourceType,
concrete_name: String,
pattern_name: String,
)
pub fn add_pattern_alias( &self, resource_type: ResourceType, concrete_name: String, pattern_name: String, )
Record a pattern alias mapping.
Arguments
resource_type- The resource typeconcrete_name- The concrete file namepattern_name- The pattern that expanded to this file