pub fn create_source_context_for_dependency(
dep: &ResourceDependency,
manifest_dir: Option<&Path>,
repo_root: Option<&Path>,
) -> SourceContextExpand description
Create appropriate source context for a resource dependency.
This function determines the correct source context based on the available information in the dependency and manifest context.