pub type ManifestOverrideIndex = HashMap<OverrideKey, ManifestOverride>;Expand description
Override index mapping resource identities to their manifest customizations.
This index is built once during resolution from the manifest dependencies and used to apply overrides to transitive dependencies that match.
Aliased Type
pub struct ManifestOverrideIndex { /* private fields */ }