Dependency handling for template context building.
This module provides functionality for extracting dependency information, custom names, and building the dependency data structure for template rendering.
Dependency handling for template context building.
This module provides functionality for extracting dependency information, custom names, and building the dependency data structure for template rendering.